print("import: 'textacy'")
import textacy

print("import: 'textacy.cache'")
import textacy.cache

print("import: 'textacy.compat'")
import textacy.compat

print("import: 'textacy.constants'")
import textacy.constants

print("import: 'textacy.corpus'")
import textacy.corpus

print("import: 'textacy.datasets'")
import textacy.datasets

print("import: 'textacy.doc'")
import textacy.doc

print("import: 'textacy.export'")
import textacy.export

print("import: 'textacy.extract'")
import textacy.extract

print("import: 'textacy.io'")
import textacy.io

print("import: 'textacy.keyterms'")
import textacy.keyterms

print("import: 'textacy.lang_utils'")
import textacy.lang_utils

print("import: 'textacy.lexicon_methods'")
import textacy.lexicon_methods

print("import: 'textacy.network'")
import textacy.network

print("import: 'textacy.preprocess'")
import textacy.preprocess

print("import: 'textacy.similarity'")
import textacy.similarity

print("import: 'textacy.spacier'")
import textacy.spacier

print("import: 'textacy.text_stats'")
import textacy.text_stats

print("import: 'textacy.text_utils'")
import textacy.text_utils

print("import: 'textacy.tm'")
import textacy.tm

print("import: 'textacy.viz'")
import textacy.viz

print("import: 'textacy.vsm'")
import textacy.vsm

